pytilities.types.numbertype.NumberType

Package pytilities :: Package types :: Module numbertype :: Class NumberType |
[hide private]
[frames] | no frames]

# Class NumberType

source code

    object --+
             |
            NumberType

Represents any number type.

Ints (, longs) and floats are subclasses of this class.

Nested Classes | [hide private]
| __metaclass__

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`